@@ -119,7 +119,7 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
     else:
 
         check_quiet_print(quiet," -> shifts are in "+shift_format.split('_')[0]+" format")
-        panav_set_chain = {}
+        panav_set_chain_offset = {}
         for chemical_shift_set in enumerate(cs_result_sets):                                  # iterate over sets of shifts
             s = cs_set(chemical_shift_set[0]+1)
             for line in chemical_shift_set[1]:
@@ -161,14 +161,18 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                     for c in s.chains:
                         out = open(output_dir+'PANAV/'+str(os.path.basename(os.path.splitext(path_to_nef_file)[0]))+"_"+c.i+"_"+str(s.i)+'_forpanav.str','w')
 
-                        panav_set_chain[str(os.path.basename(os.path.splitext(path_to_nef_file)[0]))+"_"+c.i+"_"+str(s.i)+'.panav'] = {'set':s.i,'chain':c.i}
+                        panav_set_chain_offset[str(os.path.basename(os.path.splitext(path_to_nef_file)[0]))+"_"+c.i+"_"+str(s.i)+'.panav'] = {'set':s.i,'chain':c.i}
                         old_sequence_ID = ''
                         seq_single_letter = ''
                         lines_shifts = []
                         num = 1
+                        offset = ''
                         for r in c.residues:   
+                            if offset == '':
+                                offset = r.i - 1
+                                panav_set_chain_offset[str(os.path.basename(os.path.splitext(path_to_nef_file)[0]))+"_"+c.i+"_"+str(s.i)+'.panav']['offset'] = offset # PANAV requires to start at residue 1
                             for a in r.shifts:
-                                lines_shifts.append(str(num)+' '+str(r.i)+' '+r.name+' '+a.atom_type+' '+str(a.shift) + ' 0 1')
+                                lines_shifts.append(str(num)+' '+str(r.i-offset)+' '+r.name+' '+a.atom_type+' '+str(a.shift) + ' 0 1')
                                 num+=1
                             
                             x=1        
@@ -213,11 +217,11 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                             resi = int(line[0].replace(' ','')[1:])
                             if line[1] != '      ' or line[2] != '      ' or line[3] != '      ' or line[4] != '      ' or line[5] != '      ' or line[6] != '      ': 
                                 for chemical_shift_set in enumerate(cs_result_sets):  
-                                    if panav_set_chain[panav_output]["set"] == chemical_shift_set[0]+1:
+                                    if panav_set_chain_offset[panav_output]["set"] == chemical_shift_set[0]+1:
                                         for c in s.chains:                                               # iterate over different chains
-                                            if panav_set_chain[panav_output]["chain"] == c.i:
+                                            if panav_set_chain_offset[panav_output]["chain"] == c.i:
                                                 for r in c.residues:  
-                                                    if resi == r.i:
+                                                    if resi + panav_set_chain_offset[panav_output]["offset"] == r.i:
                                                         append_reref_shift(r,'C',line[1])
                                                         append_reref_shift(r,'CA',line[2])
                                                         append_reref_shift(r,'CB',line[3])
@@ -236,10 +240,7 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                 for c in s.chains:                                               
                     for r in c.residues:  
                         r.shifts = r.reref_shifts
-
-   
-
-
+             
         for chemical_shift_set in enumerate(cs_result_sets):  
             for c in s.chains:                                               # iterate over different chains
                 for r in c.residues:                                                # append neighbours
